#
# Conditional build:
%bcond_without	doc		# documentation
%bcond_without	ffmpeg		# subtext plugin (libass+ffmpeg based)
%bcond_with	im		# imwri plugin (requires ImageMagick with Q16 or Q32 and HDRI support)
%bcond_with	sse		# use SSE/SSE2 instructions on x86 (no runtime detection)
%bcond_without	static_libs	# static libraries
#
%ifarch pentium4 %{x8664}
# x32 asm is not supported (as of 38)
%define	with_sse	1
%endif
Summary:	A video processing framework with simplicity in mind
Summary(pl.UTF-8):	Szkielet do przetwarzania obrazu stworzony z myślą o prostocie
Name:		vapoursynth
Version:	53
Release:	1
License:	LGPL v2.1+
Group:		Libraries
#Source0Download: https://github.com/vapoursynth/vapoursynth/releases
Source0:	https://github.com/vapoursynth/vapoursynth/archive/R%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	02fba7494e332078dface92171a06853
Patch0:		%{name}-sse2.patch
URL:		http://www.vapoursynth.com/
%{?with_im:BuildRequires:	ImageMagick-c++-devel >= 1:7}
BuildRequires:	autoconf >= 2.50
BuildRequires:	automake >= 1:1.11
# libavcodec libavformat libavutil
%{?with_ffmpeg:BuildRequires:	ffmpeg-devel}
%{?with_ffmpeg:BuildRequires:	libass-devel}
BuildRequires:	libstdc++-devel >= 6:4.8
BuildRequires:	libtool >= 2:2
%if %{with sse}
BuildRequires:	nasm
%endif
BuildRequires:	pkgconfig
BuildRequires:	python3-Cython
BuildRequires:	python3-devel >= 1:3.2
BuildRequires:	rpmbuild(macros) >= 1.752
BuildRequires:	sed >= 4.0
%{?with_doc:BuildRequires:	sphinx-pdg}
BuildRequires:	tesseract-devel >= 3
BuildRequires:	zimg-devel >= 2.5
%if %{with sse}
Requires:	cpuinfo(sse2)
%endif
Requires:	python3-libs >= 1:3.2
Requires:	zimg >= 2.5
%if %{without im}
Obsoletes:	vapoursynth-plugin-imwri
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# non-function std::__once_call, std::__once_callable symbols
%define		skip_post_check_so	libvapoursynth-script.so.*

%description
VapourSynth is an application for video manipulation. Or a plugin. Or
a library. It's hard to tell  because it has a core library written in
C++ and a Python module to allow video scripts to be created.

%description -l pl.UTF-8
VapourSynth to aplikacja do obróbki obrazu. Albo wtyczka. Albo
biblioteka. Trudno stwierdzić, ponieważ ma główną bibliotekę napisaną
w C++ oraz moduł Pythona pozwalający na tworzenie skryptów do obrazu.

%package plugin-imwri
Summary:	Image reader/writer plugin for VapourSynth
Summary(pl.UTF-8):	Wtyczka VapourSynth odczytująca i zapisują obrazy
Group:		Libraries
Requires:	%{name} = %{version}-%{release}

%description plugin-imwri
Image reader/writer plugin for VapourSynth.

%description plugin-imwri -l pl.UTF-8
Wtyczka VapourSynth odczytująca i zapisują obrazy.

%package plugin-ocr
Summary:	OCR plugin for VapourSynth
Summary(pl.UTF-8):	Wtyczka OCR dla VapourSyntha
Group:		Libraries
Requires:	%{name} = %{version}-%{release}

%description plugin-ocr
OCR plugin for VapourSynth.

%description plugin-ocr -l pl.UTF-8
Wtyczka OCR dla VapourSyntha.

%package plugin-subtext
Summary:	Subtitle rendering plugin for VapourSynth
Summary(pl.UTF-8):	Wtyczka VapourSynth nanosząca podpisy
Group:		Libraries
Requires:	%{name} = %{version}-%{release}

%description plugin-subtext
Subtitle rendering plugin for VapourSynth.

%description plugin-subtext -l pl.UTF-8
Wtyczka VapourSynth nanosząca podpisy.

%package devel
Summary:	Header files for VapourSynth libraries
Summary(pl.UTF-8):	Pliki nagłówkowe bibliotek VapourSynth
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	python3-devel >= 1:3.2
Requires:	zimg-devel >= 2.5

%description devel
Header files for VapourSynth libraries.

%description devel -l pl.UTF-8
Pliki nagłówkowe bibliotek VapourSynth.

%package static
Summary:	Static VapourSynth libraries
Summary(pl.UTF-8):	Statyczne biblioteki VapourSynth
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static VapourSynth libraries.

%description static -l pl.UTF-8
Statyczne biblioteki VapourSynth.

%package doc
Summary:	Documentation for VapourSynth library
Summary(pl.UTF-8):	Dokumentacja do biblioteki VapourSynth
Group:		Documentation
BuildArch:	noarch

%description doc
Documentation for VapourSynth library.

%description doc -l pl.UTF-8
Dokumentacja do biblioteki VapourSynth.

%prep
%setup -q -n %{name}-R%{version}
%patch0 -p1

%if %{without sse}
%{__sed} -i -e 's/"-mfpmath=sse -msse2"/""/' configure.ac
%endif

%build
%{__libtoolize}
%{__aclocal}
%{__autoconf}
%{__automake}
%configure \
	%{!?with_im:--disable-imwri} \
	--disable-silent-rules \
	%{!?with_ffmpeg:--disable-subtext} \
	%{!?with_static_libs:--disable-static} \
	%{!?with_sse:--disable-x86-asm}
%{__make}

%if %{with doc}
%{__make} -C doc html
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm}	$RPM_BUILD_ROOT%{py3_sitedir}/vapoursynth.la
# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libvapoursynth*.la
# dlopened modules
%{__rm} $RPM_BUILD_ROOT%{_libdir}/vapoursynth/*.la

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc ChangeLog README.md
%attr(755,root,root) %{_bindir}/vspipe
%attr(755,root,root) %{_libdir}/libvapoursynth.so
%attr(755,root,root) %{_libdir}/libvapoursynth-script.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libvapoursynth-script.so.0
%attr(755,root,root) %{py3_sitedir}/vapoursynth.so
%dir %{_libdir}/vapoursynth
%attr(755,root,root) %{_libdir}/vapoursynth/libeedi3.so
%attr(755,root,root) %{_libdir}/vapoursynth/libmiscfilters.so
%attr(755,root,root) %{_libdir}/vapoursynth/libmorpho.so
%attr(755,root,root) %{_libdir}/vapoursynth/libremovegrain.so
%attr(755,root,root) %{_libdir}/vapoursynth/libvinverse.so
%attr(755,root,root) %{_libdir}/vapoursynth/libvivtc.so

%if %{with im}
%files plugin-imwri
%defattr(644,root,root,755)
# R: ImageMagick-c++ >= 1:7
%attr(755,root,root) %{_libdir}/vapoursynth/libimwri.so
%endif

%files plugin-ocr
%defattr(644,root,root,755)
# R: tesseract
%attr(755,root,root) %{_libdir}/vapoursynth/libocr.so

%if %{with ffmpeg}
%files plugin-subtext
%defattr(644,root,root,755)
# R: libass ffmpeg
%attr(755,root,root) %{_libdir}/vapoursynth/libsubtext.so
%endif

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libvapoursynth-script.so
%{_includedir}/vapoursynth
%{_pkgconfigdir}/vapoursynth.pc
%{_pkgconfigdir}/vapoursynth-script.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libvapoursynth.a
%{_libdir}/libvapoursynth-script.a
%endif

%if %{with doc}
%files doc
%defattr(644,root,root,755)
%doc doc/_build/html/{_static,api,functions,plugins,*.html,*.js}
%endif
%changelog
* Mon Apr 26 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/vapoursynth.git;a=log;h=master

* Mon Apr 26 2021 Jakub Bogusz <qboosh@pld-linux.org> d6524fc
- updated to 53

* Sun Mar 07 2021 Jan Rękorajski <baggins@pld-linux.org> 266d43e
- unconditional noarch subpackages

* Mon Mar 01 2021 Jan Palus <atler@pld-linux.org> 2e559c1
- release 3 (by relup.sh)

* Mon Mar 01 2021 Jan Palus <atler@pld-linux.org> cc702dd
- release 2 (by relup.sh)

* Tue Jan 12 2021 Jakub Bogusz <qboosh@pld-linux.org> 87d3612
- updated to 52

* Mon Jul 06 2020 Jakub Bogusz <qboosh@pld-linux.org> e7e4ec4
- updated to 50
- updated sse2 patch
- updated genericarch,python-3.8 patches

* Sat Mar 14 2020 Jakub Bogusz <qboosh@pld-linux.org> 9e472ff
- added sse2 patch (fixes build without sse)

* Sat Dec 14 2019 Marcin Krol <hawk@tld-linux.org> 1cfd1d1
- fix patch

* Sat Dec 14 2019 Marcin Krol <hawk@tld-linux.org> 3d87d4d
- updated to 48

* Thu Oct 31 2019 Jakub Bogusz <qboosh@pld-linux.org> ba967eb
- "-embed" pc suffix only for python 3.8+

* Wed Oct 30 2019 Jan Rękorajski <baggins@pld-linux.org> 8637cc3
- rel 1

* Wed Oct 30 2019 Jan Rękorajski <baggins@pld-linux.org> cc0f3fb
- up to 47.2
- fix building with python 3.8

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 0bd660f
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sun Jul 28 2019 Jakub Bogusz <qboosh@pld-linux.org> 2f29a7a
- updated to 46

* Sat Apr 27 2019 Jakub Bogusz <qboosh@pld-linux.org> 49f229e
- updated to 45.1
- updated genericarch patch
- disable imwri plugin by default, it requires HDRI enabled ImageMagick and our is not

* Thu Aug 09 2018 Jan Rękorajski <baggins@pld-linux.org> 0e66c50
- release 7 (by relup.sh)

* Wed Aug 08 2018 Jan Rękorajski <baggins@pld-linux.org> 5d9466e
- release 6 (by relup.sh)

* Tue Jul 03 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 9adb40f
- release 5 (by relup.sh)

* Sat Apr 28 2018 Jan Rękorajski <baggins@pld-linux.org> 4b838e1
- rebuild with ffmpeg 4
- release 4 (by relup.sh)

* Tue Dec 26 2017 Jan Rękorajski <baggins@pld-linux.org> 9f61b65
- release 3 (by relup.sh)

